/**
 *
 * @author Diorgenes Felipe Grzesiuk <diorgenes@prognus.com.br>
 * @copyright Copyright 2007-2008 Prognus
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package br.com.prognus.psync.items.manager;

import java.sql.Timestamp;
import java.util.List;

import br.com.prognus.psync.exception.EntityException;
import br.com.prognus.psync.exception.PIMDBAccessException;
import br.com.prognus.psync.items.dao.PIMEntityDAO;
import br.com.prognus.psync.util.Def;

import com.funambol.framework.logging.FunambolLogger;
import com.funambol.framework.logging.FunambolLoggerFactory;

public abstract class PIMEntityManager {

	// ------------------------------------------------------------ Private data

	protected static final FunambolLogger log = FunambolLoggerFactory
			.getLogger(Def.LOGGER_NAME);

	protected PIMEntityDAO dao;

	// ---------------------------------------------------------- Public methods

	public char getItemState(String id, Timestamp t) throws EntityException {
		try {
			return dao.getItemState(id, t);
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while getting item state.", dbae);
		}
	}

	public List getAllItems() throws EntityException {

		try {
			return dao.getAllItems();
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while getting all items.", dbae);
		}
	}

	public List getNewItems(Timestamp since, Timestamp to)
			throws EntityException {

		try {
			return dao.getNewItems(since, to);
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while getting new items.", dbae);
		}
	}

	public List getUpdatedItems(Timestamp since, Timestamp to)
			throws EntityException {

		try {
			return dao.getUpdatedItems(since, to);
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while getting updated items.",
					dbae);
		}
	}

	public List getDeletedItems(Timestamp since, Timestamp to)
			throws EntityException {

		try {
			return dao.getDeletedItems(since, to);
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while getting deleted items.",
					dbae);
		}
	}

	public void removeItem(String uid) throws EntityException {

		try {
			dao.removeItem(uid);
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while deleting item.", dbae);
		}
	}

	public void removeAllItems() throws EntityException {

		try {
			dao.removeAllItems();
		} catch (PIMDBAccessException dbae) {
			throw new EntityException("Error while removing all items.", dbae);
		}
	}
}
